import 'package:backend_dart/domain/entities/user.dart';
import 'package:backend_dart/domain/interface/error.dart';
import 'package:backend_dart/domain/interface/mapper.dart';
import 'package:backend_dart/infrastructure/persistence/db/model.dart';
import 'package:fpdart/fpdart.dart';

class UserDboMapper implements IMapper<User, UserDbo> {
  @override
  TaskEither<IError, User> from(UserDbo target) => TaskEither.of(User(
        id: target.id!,
        name: target.name!,
        email: target.email!,
        password: target.password,
        createdAt: target.createdAt,
        updatedAt: target.updatedAt,
      ));

  @override
  TaskEither<IError, List<User>> listFrom(Iterable<UserDbo> targets) {
    return TaskEither.traverseList(targets.toList(), from);
  }

  @override
  TaskEither<IError, List<UserDbo>> listTo(Iterable<User> origins) {
    return TaskEither.traverseList(origins.toList(), to);
  }

  @override
  TaskEither<IError, UserDbo> to(User origin) => TaskEither.of(UserDbo(
        id: origin.id,
        name: origin.name,
        email: origin.email,
        password: origin.password,
        createdAt: origin.createdAt,
        updatedAt: origin.updatedAt,
      ));
}
